@@ -18,9 +18,9 @@
 #
 # Program: Worker.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Thu Jun 20 13:15:16 2013 +0200
-# Ident:   d297da0e4f99160448131e356837143722675862
-# Branch:  HEAD, v1.0.1, origin/master, origin/HEAD, master
+# Date:    Thu Jun 20 19:35:35 2013 +0200
+# Ident:   3fa4f4538d6472db1f6b4fd7b2c36402918fbce6
+# Branch:  <REFNAMES>
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
 # 
@@ -37,6 +37,7 @@
 # Timo Benk : 2013-05-24 08:03:19 +0200 : generic mode added
 # Timo Benk : 2013-06-13 13:59:01 +0200 : process output handling refined
 # Timo Benk : 2013-06-14 12:38:19 +0200 : open3 will never return undef
+# Timo Benk : 2013-06-20 19:33:33 +0200 : raise condition in signal handling code fixed
 #
 
 ###
@@ -149,6 +150,12 @@ sub init {
 
     $_self->{hostname} = $_cfg->{hostname};
 
+    $_self->{pid} = "n/a";
+
+    $_self->{handler_alrm} = NRun::Signal::register('ALRM', \&handler_alrm, [ \$_self ], $$);
+    $_self->{handler_int}  = NRun::Signal::register('INT',  \&handler_int,  [ \$_self ], $$);
+    $_self->{handler_term} = NRun::Signal::register('TERM', \&handler_term, [ \$_self ], $$);
+
     $_self->{O} = \*STDOUT;
     $_self->{E} = \*STDERR;
 }
@@ -158,18 +165,14 @@ sub init {
 sub handler_term {
 
     my $_self = shift;
-    my $_pid  = shift;
 
-    if ($$_pid != -128) {
+    if ($$_self->{pid} ne "n/a") {
 
-        kill(KILL => $$_pid);
-    } else {
-  
-        $$_pid = "n/a";
+        kill(KILL => $$_self->{pid});
     }
 
-    print {$$_self->{O}} "$$_self->{hostname};stdout;" . time() . ";$$;$$_pid;exit;\"exit code $NRun::Constants::CODE_SIGTERM;\"\n";
-    print {$$_self->{E}} "$$_self->{hostname};stderr;" . time() . ";$$;$$_pid;error;\"SIGTERM received\"\n";
+    print {$$_self->{O}} "$$_self->{hostname};stdout;" . time() . ";$$;$$_self->{pid};exit;\"exit code $NRun::Constants::CODE_SIGTERM;\"\n";
+    print {$$_self->{E}} "$$_self->{hostname};stderr;" . time() . ";$$;$$_self->{pid};error;\"SIGTERM received\"\n";
 }
 
 ###
@@ -177,18 +180,14 @@ sub handler_term {
 sub handler_int {
 
     my $_self = shift;
-    my $_pid  = shift;
 
-    if ($$_pid != -128) {
+    if ($$_self->{pid} ne "n/a") {
 
-        kill(KILL => $$_pid);
-    } else {
-  
-        $$_pid = "n/a";
-    }
+        kill(KILL => $$_self->{pid});
+    } 
 
-    print {$$_self->{O}} "$$_self->{hostname};stdout;" . time() . ";$$;$$_pid;exit;\"exit code $NRun::Constants::CODE_SIGINT;\"\n";
-    print {$$_self->{E}} "$$_self->{hostname};stderr;" . time() . ";$$;$$_pid;error;\"SIGINT received\"\n";
+    print {$$_self->{O}} "$$_self->{hostname};stdout;" . time() . ";$$;$$_self->{pid};exit;\"exit code $NRun::Constants::CODE_SIGINT;\"\n";
+    print {$$_self->{E}} "$$_self->{hostname};stderr;" . time() . ";$$;$$_self->{pid};error;\"SIGINT received\"\n";
 }
 
 
@@ -197,18 +196,14 @@ sub handler_int {
 sub handler_alrm {
 
     my $_self = shift;
-    my $_pid  = shift;
 
-    if ($$_pid != -128) {
+    if ($$_self->{pid} ne "n/a") {
 
-        kill(KILL => $$_pid);
-    } else {
-  
-        $$_pid = "n/a";
+        kill(KILL => $$_self->{pid});
     }
 
-    print {$$_self->{O}} "$$_self->{hostname};stdout;" . time() . ";$$;$$_pid;exit;\"exit code $NRun::Constants::CODE_SIGALRM;\"\n";
-    print {$$_self->{E}} "$$_self->{hostname};stderr;" . time() . ";$$;$$_pid;error;\"SIGALRM received\"\n";
+    print {$$_self->{O}} "$$_self->{hostname};stdout;" . time() . ";$$;$$_self->{pid};exit;\"exit code $NRun::Constants::CODE_SIGALRM;\"\n";
+    print {$$_self->{E}} "$$_self->{hostname};stderr;" . time() . ";$$;$$_self->{pid};error;\"SIGALRM received\"\n";
 }
 
 ###
@@ -227,22 +222,12 @@ sub do {
 
     chomp($_cmd);
 
-    my $pid = -128;
-
-    my $handler_alrm = NRun::Signal::register('ALRM', \&handler_alrm, [ \$_self, \$pid ], $$);
-    my $handler_int  = NRun::Signal::register('INT',  \&handler_int,  [ \$_self, \$pid ], $$);
-    my $handler_term = NRun::Signal::register('TERM', \&handler_term, [ \$_self, \$pid ], $$);
-
     eval{
 
-        $pid = open3(\*CMDIN, \*CMDOUT, \*CMDERR, "$_cmd");
+        $_self->{pid} = open3(\*CMDIN, \*CMDOUT, \*CMDERR, "$_cmd");
     };
     if ($@) {
 
-        NRun::Signal::deregister('ALRM', $handler_alrm);
-        NRun::Signal::deregister('INT',  $handler_int);
-        NRun::Signal::deregister('TERM', $handler_term);
-
         print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;n/a;debug;\"exec $_cmd\"\n";
         print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;n/a;error;\"$@\"\n";
         print {$_self->{O}} "$_self->{hostname};stdout;" . time() . ";$$;n/a;exit;\"exit code $NRun::Constants::EXECUTION_FAILED\"\n";
@@ -250,7 +235,7 @@ sub do {
         return $NRun::Constants::EXECUTION_FAILED;
     }
     
-    print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;$pid;debug;\"exec $_cmd\"\n";
+    print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;$_self->{pid};debug;\"exec $_cmd\"\n";
 
     my $selector = IO::Select->new();
     $selector->add(\*CMDOUT, \*CMDERR);
@@ -264,14 +249,14 @@ sub do {
                 while (my $line = <$fh>) {
 
                     chomp($line);
-                    print {$_self->{O}} "$_self->{hostname};stdout;" . time() . ";$$;$pid;output;\"$line\"\n";
+                    print {$_self->{O}} "$_self->{hostname};stdout;" . time() . ";$$;$_self->{pid};output;\"$line\"\n";
                 }
             } elsif (fileno($fh) == fileno(CMDERR)) {
 
                 while (my $line = <$fh>) {
 
                     chomp($line);
-                    print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;$pid;output;\"$line\"\n";
+                    print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;$_self->{pid};output;\"$line\"\n";
                 }
             }
 
@@ -282,13 +267,11 @@ sub do {
     close(CMDOUT);
     close(CMDERR);
 
-    waitpid($pid, 0);
+    waitpid($_self->{pid}, 0);
 
-    print {$_self->{O}} "$_self->{hostname};stdout;" . time() . ";$$;$pid;exit;\"exit code " . ($? >> 8) . "\"\n";
+    print {$_self->{O}} "$_self->{hostname};stdout;" . time() . ";$$;$_self->{pid};exit;\"exit code " . ($? >> 8) . "\"\n";
 
-    NRun::Signal::deregister('ALRM', $handler_alrm);
-    NRun::Signal::deregister('INT',  $handler_int);
-    NRun::Signal::deregister('TERM', $handler_term);
+    $_self->{pid} = "n/a";
 
     return ($? >> 8);
 }
@@ -309,6 +292,10 @@ sub end {
     print {$_self->{O}} "$_self->{hostname};stdout;" . time() . ";$$;n/a;end;\n";
     print {$_self->{E}} "$_self->{hostname};stderr;" . time() . ";$$;n/a;end;\n";
 
+    NRun::Signal::deregister('ALRM', $_self->{handler_alrm});
+    NRun::Signal::deregister('INT',  $_self->{handler_int});
+    NRun::Signal::deregister('TERM', $_self->{handler_term});
+    
     open(NULL, ">/dev/null");
 
     $_self->{O} = \*NULL;
